"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegdacRawMapper = exports.RegdacMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const aw_antelope_1 = require("@alien-worlds/aw-antelope");
const entities_1 = require("../../domain/entities");
class RegdacMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    constructor() {
        super();
        this.mappingFromEntity.set('owner', {
            key: 'owner',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('dacId', {
            key: 'dac_id',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('dacSymbol', {
            key: 'dac_symbol',
            mapper: (value) => new aw_antelope_1.ExtendedSymbolMongoMapper().fromEntity(value),
        });
        this.mappingFromEntity.set('title', {
            key: 'title',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('refs', {
            key: 'refs',
            mapper: (values) => values.map(value => new aw_antelope_1.PairMongoMapper().fromEntity(value)),
        });
        this.mappingFromEntity.set('accounts', {
            key: 'accounts',
            mapper: (values) => values.map(value => new aw_antelope_1.PairMongoMapper().fromEntity(value)),
        });
    }
    toEntity(mongoModel) {
        const { owner, dac_id, dac_symbol, title, refs, accounts, _id, ...rest } = mongoModel;
        return entities_1.Regdac.create(owner || '', dac_id || '', dac_symbol ? new aw_antelope_1.ExtendedSymbolMongoMapper().toEntity(dac_symbol) : aw_antelope_1.ExtendedSymbol.getDefault(), title || '', refs?.map(value => new aw_antelope_1.PairMongoMapper().toEntity(value)) || [], accounts?.map(value => new aw_antelope_1.PairMongoMapper().toEntity(value)) || [], _id instanceof aw_storage_mongodb_1.MongoDB.ObjectId ? _id.toString() : undefined, rest);
    }
}
exports.RegdacMongoMapper = RegdacMongoMapper;
class RegdacRawMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('Method not implemented');
    }
    toEntity(rawModel) {
        const { owner, dac_id, dac_symbol, title, refs, accounts, ...rest } = rawModel;
        return entities_1.Regdac.create(owner || '', dac_id || '', dac_symbol ? new aw_antelope_1.ExtendedSymbolRawMapper().toEntity(dac_symbol) : aw_antelope_1.ExtendedSymbol.getDefault(), title || '', refs?.map(value => new aw_antelope_1.PairRawMapper().toEntity(value)) || [], accounts?.map(value => new aw_antelope_1.PairRawMapper().toEntity(value)) || [], undefined, rest);
    }
}
exports.RegdacRawMapper = RegdacRawMapper;
