"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndexWorldsDeltaProcessorTaskMapper = exports.IndexWorldsDeltaMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const enums_1 = require("../../domain/enums");
const dacglobals_mapper_1 = require("./dacglobals.mapper");
const dacs_mapper_1 = require("./dacs.mapper");
const nftcache_mapper_1 = require("./nftcache.mapper");
class IndexWorldsDeltaMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    fromEntity(entity) {
        let entityData;
        switch (entity.table) {
            case enums_1.IndexWorldsTableName.Dacglobals:
                entityData = new dacglobals_mapper_1.DacglobalsMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsTableName.Dacs:
                entityData = new dacs_mapper_1.DacsMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.IndexWorldsTableName.Nftcache:
                entityData = new nftcache_mapper_1.NftcacheMongoMapper().fromEntity(entity.data);
                break;
        }
        const model = {
            block_timestamp: entity.blockTimestamp,
            block_num: new aw_storage_mongodb_1.MongoDB.Long(entity.blockNumber),
            code: entity.code,
            scope: entity.scope,
            table: entity.table,
            data: entityData,
            payer: entity.payer,
            primary_key: new aw_storage_mongodb_1.MongoDB.Long(entity.primaryKey),
            present: entity.present,
        };
        if (entity.id && aw_storage_mongodb_1.MongoDB.ObjectId.isValid(entity.id)) {
            model._id = new aw_storage_mongodb_1.MongoDB.ObjectId(entity.id);
        }
        return model;
    }
    toEntity(mongoModel) {
        let data;
        switch (mongoModel.table) {
            case enums_1.IndexWorldsTableName.Dacglobals:
                data = new dacglobals_mapper_1.DacglobalsMongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.IndexWorldsTableName.Dacs:
                data = new dacs_mapper_1.DacsMongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.IndexWorldsTableName.Nftcache:
                data = new nftcache_mapper_1.NftcacheMongoMapper().toEntity(mongoModel.data);
                break;
        }
        const { _id, block_num, code, scope, table, payer, primary_key, present, block_timestamp, } = mongoModel;
        return new aw_core_1.ContractDelta(_id.toString(), (0, aw_core_1.parseToBigInt)(block_num), code, scope, table, data, payer, (0, aw_core_1.parseToBigInt)(primary_key), present, block_timestamp);
    }
}
exports.IndexWorldsDeltaMongoMapper = IndexWorldsDeltaMongoMapper;
class IndexWorldsDeltaProcessorTaskMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('method not implemented');
    }
    toEntity(rawModel) {
        let data;
        switch (rawModel.table) {
            case enums_1.IndexWorldsTableName.Dacglobals:
                data = new dacglobals_mapper_1.DacglobalsRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsTableName.Dacs:
                data = new dacs_mapper_1.DacsRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.IndexWorldsTableName.Nftcache:
                data = new nftcache_mapper_1.NftcacheRawMapper().toEntity(rawModel.data);
                break;
        }
        const { block_num, code, scope, table, payer, primary_key, present, block_timestamp, } = rawModel;
        return new aw_core_1.ContractDelta('', (0, aw_core_1.parseToBigInt)(block_num), code, scope, table, data, payer, (0, aw_core_1.parseToBigInt)(primary_key), present, block_timestamp);
    }
}
exports.IndexWorldsDeltaProcessorTaskMapper = IndexWorldsDeltaProcessorTaskMapper;
