"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupIndexWorldsContractService = exports.setupIndexWorldsDeltaRepository = exports.setupIndexWorldsActionRepository = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const mappers_1 = require("./actions/data/mappers");
const data_sources_1 = require("./actions/data/data-sources");
const repositories_1 = require("./actions/domain/repositories");
const index_worlds_contract_service_1 = require("./services/index-worlds-contract.service");
const index_worlds_contract_service_impl_1 = require("./services/index-worlds-contract.service-impl");
const mappers_2 = require("./deltas/data/mappers");
const data_sources_2 = require("./deltas/data/data-sources");
const repositories_2 = require("./deltas/domain/repositories");
const setupIndexWorldsActionRepository = async (mongo, container) => {
    let mongoSource;
    if (mongo instanceof aw_storage_mongodb_1.MongoSource) {
        mongoSource = mongo;
    }
    else {
        mongoSource = await aw_storage_mongodb_1.MongoSource.create(mongo);
    }
    const mapper = new mappers_1.IndexWorldsActionMongoMapper();
    const repository = new aw_core_1.RepositoryImpl(new data_sources_1.IndexWorldsActionMongoSource(mongoSource), mapper, new aw_storage_mongodb_1.MongoQueryBuilders(mapper));
    if (container) {
        container
            .bind(repositories_1.IndexWorldsActionRepository.Token)
            .toConstantValue(repository);
    }
    return repository;
};
exports.setupIndexWorldsActionRepository = setupIndexWorldsActionRepository;
const setupIndexWorldsDeltaRepository = async (mongo, container) => {
    let mongoSource;
    if (mongo instanceof aw_storage_mongodb_1.MongoSource) {
        mongoSource = mongo;
    }
    else {
        mongoSource = await aw_storage_mongodb_1.MongoSource.create(mongo);
    }
    const mapper = new mappers_2.IndexWorldsDeltaMongoMapper();
    const repository = new aw_core_1.RepositoryImpl(new data_sources_2.IndexWorldsDeltaMongoSource(mongoSource), mapper, new aw_storage_mongodb_1.MongoQueryBuilders(mapper));
    if (container) {
        container
            .bind(repositories_2.IndexWorldsDeltaRepository.Token)
            .toConstantValue(repository);
    }
    return repository;
};
exports.setupIndexWorldsDeltaRepository = setupIndexWorldsDeltaRepository;
const setupIndexWorldsContractService = (antelopeRpcSourceImpl, serviceUrl, container) => {
    const service = new index_worlds_contract_service_impl_1.IndexWorldsContractServiceImpl(antelopeRpcSourceImpl, serviceUrl);
    if (container) {
        container
            .bind(index_worlds_contract_service_1.IndexWorldsContractService.Token)
            .toConstantValue(service);
    }
    return service;
};
exports.setupIndexWorldsContractService = setupIndexWorldsContractService;
